import "../stylesheets/PlantCard.css";
import {Link} from "react-router-dom";
import {Plant} from "../utils/schemas";
import QuickActionButton, {QuickActionButtonProps} from "./QuickActionButton.tsx";

type PlantCardProps = {
    plant: Plant,
    quickActions?: QuickActionButtonProps[]
}

export default function PlantCard({plant, quickActions}: PlantCardProps) {
    return (
        <>
            <li className="plantCard shadow-light">
                <Link to={`/pflanze/${plant.id}`} className="plantCardLink">
                    <h2>{plant.name}</h2>
                    <img src={plant.imageUrl} alt={`Photo of plant: {plant.name}`} className="plantCardImg"/>
                </Link>
                {
                    quickActions && quickActions.map(
                        (action, index) =>
                            <QuickActionButton iconClassName={action.iconClassName}
                                               tooltip={action.tooltip}
                                               onClick={action.onClick}
                                               key={index}
                            />
                    )
                }
            </li>
        </>
    );
}
